==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hit");
define("_BROWSERS","Tarayclar");
define("_OPERATINGSYS","letim Sistemi");
define("_UNKNOWN","Bilinmeyen");
define("_OTHER","Dier / Bilinmeyen");
define("_MISCSTATS","Dier statistikler");
define("_REGUSERS","Kaytl Kullanc:");
define("_ACTIVEAUTHORS","Aktif Editr:");
define("_STORIESPUBLISHED","Yaynlanan Haber:");
define("_SACTIVETOPICS","Aktif Konu:");
define("_COMMENTSPOSTED","Gnderilen Yorum:");
define("_SSPECIALSECT","zel Blm:");
define("_ARTICLESSEC","Blmlerdeki Makale:");
define("_LINKSINLINKS","Balant:");
define("_LINKSCAT","Balant Kategorisi:");
define("_NEWSWAITING","Bekleyen Haber:");
define("_NUKEVERSION","PHP-Nuke Srm:");
define("_SEARCHENGINES","Arama Motorlar");
define("_BOTS","Robotlar/rmcekler");
define("_STATS","Eriim statistikleri");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hit");
define("_BROWSERS","Tarayclar");
define("_OPERATINGSYS","letim Sistemi");
define("_UNKNOWN","Bilinmeyen");
define("_OTHER","Dier / Bilinmeyen");
define("_MISCSTATS","Dier statistikler");
define("_REGUSERS","Kaytl Kullanc:");
define("_ACTIVEAUTHORS","Aktif Editr:");
define("_STORIESPUBLISHED","Yaynlanan Haber:");
define("_SACTIVETOPICS","Aktif Konu:");
define("_COMMENTSPOSTED","Gnderilen Yorum:");
define("_SSPECIALSECT","zel Blm:");
define("_ARTICLESSEC","Blmlerdeki Makale:");
define("_LINKSINLINKS","Balant:");
define("_LINKSCAT","Balant Kategorisi:");
define("_NEWSWAITING","Bekleyen Haber:");
define("_NUKEVERSION","PHP-Nuke Srm:");
define("_SEARCHENGINES","Arama Motorlar");
define("_BOTS","Robotlar/rmcekler");
define("_STATS","Eriim statistikleri");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
